@@ -80,7 +80,8 @@ from .models.feature_store_run import FeatureStoreRun
 from .models.feature_template import FeatureTemplate, TemplateId, TemplateName
 from .models.feature_template_creation_request import FeatureTemplateCreationRequest
 from .models.file_format import CSV, FileFormat, Parquet, Orc
-from .models.jobs import RunStatus, FeatureStoreRunId, TableMonitoringRunId
+from .models.jobs import RunStatus, FeatureStoreRunId
+from .models.table_monitoring import TableMonitoringRunId
 from .models.merge_request import MergeRequest, MergeRequestCreationRequest, MergeRequestId, MergeRequestComment
 from .models.ref import Ref, BranchRef
 from .models.table import Table, TableId, TableName
